#!/bin/sh

# Abort execution if anything returns with a non-zero status code.
set -e

: "${CTEE_DEKPATH:=/etc/pgee}"
: "${CTEE_CLUSTER:=main}"
: "${CTEE_PGMVER:=14}"
: "${CTEE_GPGBIN:=gpg}" # Sometimes it is `gpg2`.
: "${CTEE_KEYLEN:=24}"  # Or 16, or 32.

_key_dir="$CTEE_DEKPATH/$CTEE_PGMVER/$CTEE_CLUSTER"
_key_path="$_key_dir/key.asc"

# Generate a new data encryption key, if it does not exist.
if [ ! -f "$_key_path" ]
then
	mkdir -p $_key_dir
	_dek=$(openssl rand -hex "$CTEE_KEYLEN")
	echo "$_dek" | \
		"$CTEE_GPGBIN" --encrypt   \
		--armor \
		--recipient "$CTEE_GPGFP" \
		--output "$_key_path"
fi

# Decrypt the data encryption key, and print it to stdout.
"$CTEE_GPGBIN" --quiet --decrypt "$_key_path"
